<?php
/**
  * @package MediaWiki
  * @subpackage Language
  */

require_once( "LanguageUtf8.php" );

# NOTE: To turn off "Current Events" in the sidebar,
# set "currentevents" => "-"

# The names of the namespaces can be set here, but the numbers
# are magical, so don't change or move them!  The Namespace class
# encapsulates some of the magic-ness.
#
/* private */ $wgNamespaceNamesSr = array(
	NS_MEDIA            => "Media",
	NS_SPECIAL          => "Посебно",
	NS_MAIN             => "",
	NS_TALK             => "Разговор",
	NS_USER             => "Корисник",
	NS_USER_TALK        => "Разговор_са_корисником",
	NS_PROJECT          => $wgMetaNamespace,
	NS_PROJECT_TALK     => ($wgMetaNamespaceTalk ? $wgMetaNamespaceTalk : "Разговор_о_".$wgMetaNamespace ),
	NS_IMAGE            => "Слика",
	NS_IMAGE_TALK       => "Разговор_о_слици",
	NS_MEDIAWIKI        => "МедијаВики",
	NS_MEDIAWIKI_TALK   => "Разговор_о_МедијаВикију",
	NS_TEMPLATE         => 'Шаблон',
	NS_TEMPLATE_TALK    => 'Разговор_о_шаблону',
	NS_HELP             => 'Помоћ',
	NS_HELP_TALK        => 'Разговор_о_помоћи',
	NS_CATEGORY         => 'Категорија',
	NS_CATEGORY_TALK    => 'Разговор_о_категорији',
) + $wgNamespaceNamesEn;

/* private */ $wgQuickbarSettingsSr = array(
 "Никаква", "Причвршћена лево", "Причвршћена десно", "Плутајућа лево"
);

/* private */ $wgSkinNamesSr = array(
 "Обична", "Носталгија", "Келнско плаво", "Педингтон", "Монпарнас"
) + $wgSkinNamesEn;

/* private */ $wgDateFormatsSr = array(
	'Није битно',
	'06:12, 5. јануар 2001.',
	'06:12, 5 јануар 2001',
	'06:12, 05.01.2001.',
	'06:12, 5.1.2001.',
	'06:12, 5. јан 2001.',
	'06:12, 5 јан 2001',
	'6:12, 5. јануар 2001.',
	'6:12, 5 јануар 2001',
	'6:12, 05.01.2001.',
	'6:12, 5.1.2001.',
	'6:12, 5. јан 2001.',
	'6:12, 5 јан 2001',
);



/* NOT USED IN STABLE VERSION */
/* private */ $wgMagicWordsSr = array(
#   ID                                 CASE  SYNONYMS
	MAG_REDIRECT             => array( 0,    "#преусмери"              ),
	MAG_NOTOC                => array( 0,    "__БЕЗСАДРЖАЈА__"              ),
	MAG_START                => array( 0,    "__ПОЧЕТАК__"              ),
	MAG_CURRENTMONTH         => array( 1,    "{{ТРЕНУТНИМЕСЕЦ}}"       ),
	MAG_CURRENTMONTHNAME     => array( 1,    "{{ИМЕТРЕНУТНОГМЕСЕЦА}}"   ),
	MAG_CURRENTDAY           => array( 1,    "{{ТРЕНУТНИДАН}}"         ),
	MAG_CURRENTDAYNAME       => array( 1,    "{{ИМЕТРЕНУТНОГДАНА}}"     ),
	MAG_CURRENTYEAR          => array( 1,    "{{ТРЕНУТНАГОДИНА}}"        ),
	MAG_CURRENTTIME          => array( 1,    "{{ТРЕНУТНОВРЕМЕ}}"        ),
	MAG_NUMBEROFARTICLES     => array( 1,    "{{БРОЈЧЛАНАКА}}"   ),
	MAG_CURRENTMONTHNAMEGEN  => array( 1,    "{{ГЕНЕРИСАНОИМЕТРЕНУТНОГМЕСЕЦА}}"),
	MAG_SUBST                => array( 1,    "{{ПОДСТ:$1}}"           ),
	MAG_MSGNW                => array( 1,    "{{НВПОР:$1}}"           )
);

/* private */ $wgAllMessagesSr = array(

# User Toggles
#
"tog-underline" => "Подвуци везе",
"tog-highlightbroken" => "Форматирај покварене везе <a href=\"\" class=\"new\">овако</a> (алтернатива: овако<a href=\"\" class=\"internal\">?</a>).",
"tog-justify" => "Поравнај пасусе",
"tog-hideminor" => "Сакриј мале измене у списку скорашњих променама",
"tog-usenewrc" => "Побољшана списку скорашњих промена (не за све бровсере)",
"tog-numberheadings" => "Аутоматски нумериши поднаслове",
"tog-showtoolbar" => "Show edit toolbar",
"tog-editondblclick" => "Мењај странице двоструким кликом (захтева JavaScript)",
"tog-editsection"=>"Омогући измену делова [мењај] везама",
"tog-editsectiononrightclick"=>"Омогући измену делова десним кликом<br /> на њихове наслове (захтева JavaScript)",
"tog-showtoc"=>"Прикажи садржај<br />(у свим чланцима са више од три поднаслова)",
"tog-rememberpassword" => "Памти шифру кроз више сеанси",
"tog-editwidth" => "Поље за измене има пуну ширину",
"tog-watchdefault" => "Додај странице које мењам у мој списак гледања",
"tog-minordefault" => "Означи све измене малим испрва",
"tog-previewontop" => "Покажи предпреглед пре поља за измену а не после њега",
"tog-nocache" => "Онемогући кеширање страница",

# Dates
#

'sunday' => "Недеља",
'monday' => "Понедељак",
'tuesday' => "Уторак",
'wednesday' => "Среда",
'thursday' => "Четвртак",
'friday' => "Петак",
'saturday' => "Субота",
'january' => "јануар",
'february' => "фебруар",
'march' => "март",
'april' => "април",
'may_long' => "мај",
'june' => "јун",
'july' => "јул",
'august' => "август",
'september' => "септембар",
'october' => "октобар",
'november' => "новембар",
'december' => "децембар",
'jan' => "јан",
'feb' => "феб",
'mar' => "мар",
'apr' => "апр",
'may' => "мај",
'jun' => "јун",
'jul' => "јул",
'aug' => "авг",
'sep' => "сеп",
'oct' => "окт",
'nov' => "нов",
'dec' => "дец",

# Bits of text used by many pages:
#
"categories" => "Категорије страница",
"category" => "категорија",
"category_header" => "Чланака у категорији: \"$1\"",
"subcategories" => "Подкатегорије",

"linktrail" => "/^([абвгдђежзијклљмнњопрстћуфхцчџш]+)(.*)$/usD",
"mainpage"  => "Главна страна",
"mainpagetext" => "Вики софтвер је успешно инсталиран.",
"about"   => "О...",
"aboutsite"      => "О Википедији",
"aboutpage"  => "{{ns:4}}:О",
"help"   => "Помоћ",
"helppage"  => "{{ns:4}}:Помоћ",
"bugreports" => "Пријаве грешака",
"bugreportspage" => "{{ns:4}}:Пријаве_грешака",
"faq"   => "FAQ",
"faqpage"  => "{{ns:4}}:FAQ",
"edithelp"  => "Помоћ! Како се мења страна?",
"edithelppage" => "{{ns:4}}:Како_се_мења_страна",
"cancel"  => "Поништи",
"qbfind"  => "Пронађи",
"qbbrowse"  => "Прелиставај",
"qbedit"  => "Измени",
"qbpageoptions" => "Опције странице",
"qbpageinfo" => "Информације о страници",
"qbmyoptions" => "Моје опције",
"mypage"  => "Моја страница",
"mytalk"  => "Мој разговор",
"currentevents" => "Тренутни догађаји",
"errorpagetitle" => "Грешка",
"returnto"  => "Повратак на $1.",
"tagline"       => "Из Википедије, слободне енциклопедије.",
"whatlinkshere" => "Странице које су повезане овде",
"help"   => "Помоћ",
"search"  => "Тражи",
"go"  => "Иди",
"history"  => "Историја странице",
"printableversion" => "Верзија за штампу",
"editthispage" => "Измени ову страницу",
"deletethispage" => "Обриши ову страницу",
"protectthispage" => "Заштити ову страницу",
"unprotectthispage" => "Уклони заштиту са ове странице",
"newpage" => "Нова страница",
"talkpage"  => "Разговор о овој страници",
"postcomment"   => "Пошаљи коментар",
"articlepage" => "Погледај чланак",
"subjectpage" => "Погледај тему", # For compatibility
"userpage" => "Погледај корисничку страну",
"wikipediapage" => "Погледај страну о овој страни",
"imagepage" =>  "Погледај страну слике",
"viewtalkpage" => "Погледај расправу",
"otherlanguages" => "Остали језици",
"redirectedfrom" => "(Преусмерено са $1)",
"lastmodified" => "Ова страница је последњи пут измењена $1.",
"viewcount"  => "Овој страници је приступљено $1 пута.",
"printsubtitle" => "(Са {{SERVER}})",
"protectedpage" => "Заштићена страница",
"administrators" => "{{ns:4}}:Администратори",
"sysoptitle" => "Неопходан је сисопски приступ",
"sysoptext"  => "Акцију коју сте затражили могу
извести само корисници са \"сисоп\" статусом.
Погледајте $1.",
"developertitle" => "Неоходан је девелоперски приступ",
"developertext" => "Акцију коју сте затражили могу
извести само корисници са \"девелопер\" статусом.
Погледајте $1.",
"nbytes"  => "$1 бајтова",
"go"   => "Иди",
"ok"   => "Да",
"sitetitle"  => "{{SITENAME}}",
"sitesubtitle" => "Слободна енциклопедија",
"retrievedfrom" => "Добављено из \"$1\"",
"newmessages" => "Имате $1.",
"newmessageslink" => "нових порука",
"editsection"=>"измени",
"toc" => "Садржај",
"showtoc" => "прикажи",
"hidetoc" => "сакриј",
"thisisdeleted" => "Погледај или врати $1?",
"restorelink" => "$1 обрисаних измена",
/*
</pre>

==Део 2==
<pre>
*/
# Main script and global functions
#
"nosuchaction" => "Нема такве акције",
"nosuchactiontext" => "Акција наведена у УРЛ-у није
препозната од стране Википедијиног софтвера.",
"nosuchspecialpage" => "Нема такве посебне странице",
"nospecialpagetext" => "Хтели сте посебну страницу која није
препозната од стране Википедијиног софтвера.",

# General errors
#
"error"   => "Грешка",
"databaseerror" => "Грешка у бази",
"dberrortext" => "Десила се синтаксна грешка упита базе.
Ово је могуће због илегалног упита,
или могуће грешке у софтверу.
Последњи покушани упит је био:
<blockquote><tt>$1</tt></blockquote>
из функције \"<tt>$2</tt>\".
MySQL је вратио грешку \"<tt>$3: $4</tt>\".",
"dberrortextcl" => "Десила се синтаксна грешка упита базе.
Последњи покушани упит је био:
\"$1\"
из функције \"$2\".
MySQL је вратио грешку \"$3: $4\".\n",
"noconnect"  => "Жалимо! Вики има неке техничке потешкоће, и не може да се повеже се сервером базе.",
"nodb"   => "Не могу да изаберем базу $1",
"cachederror"  => "Ово је кеширана копија захтеване странице, и можда није најновија.",
"readonly"  => "База је закључана",
"enterlockreason" => "Унесите разлог за закључавање, укључујући процену
времена откључвања",
"readonlytext" => "Википедијина база је тренутно закључана за нове
уносе и остале измене, вероватно због рутинског одржавања,
после чега ће бити враћена у уобичајено стање.
Администратор који ју је закључао понудио је ово објашњење:
<p>$1",
"missingarticle" => "База није нашла текст странице
који је требала, назван \"$1\".

<p>Ово је обично изазвано праћењем застарелог \"разл\" или везе ка историји
странице која је обрисана.

<p>Ако ово није случај, можда сте пронашли грешку у софтверу.
Молимо вас пријавите ово једном од администратора, заједно са УРЛ-ом.",
"internalerror" => "Интерна грешка",
"filecopyerror" => "Не могу да ископирам фајл \"$1\" на \"$2\".",
"filerenameerror" => "Не могу да променим име фајла \"$1\" у \"$2\".",
"filedeleteerror" => "Не могу да обришем фајл \"$1\".",
"filenotfound" => "Не могу да нађем фајл \"$1\".",
"unexpected" => "Неочекивана вредност: \"$1\"=\"$2\".",
"formerror"  => "Грешка: не могу да пошаљем упитник",
"badarticleerror" => "Ова акција не може бити извршена на овој страници.",
"cannotdelete" => "Не могу да обришем наведену страницу или слику. (Могуће је да ју је неко други већ обрисао.)",
"badtitle"  => "Лош наслов",
"badtitletext" => "Захтевани наслов странице је био неисправан, празан или
неисправно повезан међујезички или међувики наслов.",
"perfdisabled" => "Жалимо! Ова могућност је привремено онемогућена јер успорава базу до те мере да више нико не може да користи вики.",
"perfdisabledsub" => "Овде је снимљена копија $1:",

# Login and logout pages
#
"logouttitle" => "Одјави се",
"logouttext" => "Сада сте одјављени. Можете да наставите да користите Википедију анонимно, или се поново пријавити као други корисник. Обратите пажњу да неке странице могу наставити да се приказују као да сте још увек пријављени, док не очистите кеш свог бровсера.\n",

"welcomecreation" => "<h2>Добродошли, $1!</h2><p>Ваш налог је креиран.
Не заборавите да прилагодите себи своја Википедијина подешавања.",

"loginpagetitle" => "Пријављивање",
"yourname"  => "Ваше корисничко име",
"yourpassword" => "Ваша шифра",
"yourpasswordagain" => "Поново укуцајте шифру",
"newusersonly" => " (само за нове кориснике)",
"remembermypassword" => "Запамти моју шифру током више сеанси.",
"loginproblem" => "<b>Било је проблема са вашим пријављивањем.</b><br />Пробајте поново!",
"alreadyloggedin" => "<strong>Корисниче $1, већ сте пријављени!</strong><br />\n",

"login"   => "Пријави се",
"userlogin"  => "Пријави се",
"logout"  => "Одјави се",
"userlogout" => "Одјави се",
"notloggedin" => "Нисте пријављени",
"createaccount" => "Направи нови налог",
"createaccountmail" => "e-поштом",
"badretype"  => "Шифре које сте унели се не поклапају.",
"userexists" => "Корисничко име које сте унели већ јеу употреби. Молим вас изаберите друго име.",
"youremail"  => "Ваша е-адреса*",
"yournick"  => "Ваш надимак (за потписе)",
"emailforlost" => "* Уношење адресе е-поште није обавезно.  Али оно ће омогућити људима да
вас контатирају кроз сајт а да не морате да им откријете
своју адресу, а такође ће вам помоћи ако заборавите вашу
шифру.",
"loginerror" => "Грешка при пријављивању",
"noname"  => "Нисте изабрали исправно корисничко име.",
"loginsuccesstitle" => "Пријављивање успешно",
"loginsuccess" => "Сада сте пријављени на Википедију као \"$1\".",
"nosuchuser" => "Не постоји корисник са именом \"$1\".
Проверите ваше куцање, или употребите доњи упитник да направите нови кориснички налог.",
"wrongpassword" => "Шифра коју сте унели је неисправна. Молимо покушајте поново.",
"mailmypassword" => "Пошаљи ми нову шифру",
"passwordremindertitle" => "Vikipedijin podsetnik za sifru",
"passwordremindertext" => "Neko (verovatno vi, sa IP adrese $1)
je zahtevao da vam posaljemo novu sifru za prijavljivanje na Vikipediju.
Sifra za korisnika \"$2\" je sada \"$3\".
Sada biste trebali da se ulogujete i promenite svoju sifru.",
"noemail"  => "Не постоји е-адреса за корисника \"$1\".",
"passwordsent" => "Нова шифра је послата на е-адресу
корисника \"$1\".
Молимо вас улогујте се пошто је примите.",

# Edit pages
#
"summary"  => "Уопштено",
"subject"  => "Тема/наслов",
"minoredit"  => "Ово је мала измена",
"watchthis"  => "Надгледај овај чланак",
"savearticle" => "Сними страницу",
"preview"  => "Предпреглед",
"showpreview" => "Прикажи предпреглед",
"blockedtitle" => "Корисник је блокиран",
"blockedtext" => "Ваше корисничко име или ИП адреса је блокирана од стране $1.
Дати разлог је следећи:<br />''$2''<p>Можете се обратити $1 или неком другом
[[{{ns:4}}:администратори|администратору]] да бисте разговарали о блокади.",
"whitelistedittitle" => "Обавезно је пријављивање за мењање",
"whitelistedittext" => "Морате да се [[Посебно:Пријављивање|пријавите]] да бисте мењали чланке.",
"whitelistreadtitle" => "Обавезно је пријављивање за читање",
"whitelistreadtext" => "Морате да се [[Посебно:Пријављивање|пријавите]] да бисте читали чланке.",
"whitelistacctitle" => "Није вам дозвољено да направите налог",
"whitelistacctext" => "Да би вам било дозвољено да направите налоге на овом Викију морате да се [[Посебно:Пријављивање|пријавите]] и имате одговарајућа овчашћења.",
"accmailtitle" => "Шифра послата.",
"accmailtext" => "Шифра за '$1' је послата на $2.",
"newarticle" => "(Нови)",
"newarticletext" =>
"Пратили сте везу ка страници која још на постоји.
Да бисте створили страницу, почните да куцате у поље испод
(погледајте [[{{ns:4}}:Помоћ|помоћ]] за више информација).
Ако сте овде дошли грешком, само стисните '''back''' дугме вашег бровсера.",
"anontalkpagetext" => "---- ''Ово је страница за разговор за анонимног корисника који још није направио налог или га не користи. Због тога морамо да користимо бројчану [[ИП адреса|ИП адресу]] да бисмо идентификовали њега или њу. Такву адресу може делити више корисника. Ако сте анонимни корисник и мислите да су вам упућене небитне примедбе, молимо вас да [[Посебно:Пријављивање|направите налог или се пријавите]] да бисте избегли будућу забуну са осталим анонимним корисницима.'' ",
"noarticletext" => "(Тренутно нема текста на овој страници)",
"updated"  => "(Освежено)",
"note"   => "<strong>Пажња:</strong> ",
"previewnote" => "Запамтите да је ово само предпреглед, и да још није снимљен!",
"previewconflict" => "Овај предпреглед осликава како ће текст у
текстуалном пољу изгледати ако се одлучите да га снимите.",
"editing"  => "Мењам $1",
"editingsection"  => "Мењам $1 (део)",
"editingcomment"  => "Мењам $1 (коментар)",
"editconflict" => "Сукобљене измене: $1",
"explainconflict" => "Неко други је променио ову страницу откад сте ви почели да је мењате.
Горње текстуално поље садржи текст странице какв тренутно постоји.
Ваше измене су приказане у доњем тексту.
Мораћете да унесете своје промене у постојећи текст.
<b>Само</b> текст у горњем текстуалном пољу ће бити снимљен када
притиснете \"Сними страницу\".<br />",
"yourtext"  => "Ваш текст",
"storedversion" => "Ускладиштена верзија",
"editingold" => "<strong>ПАЖЊА: Ви мењате старију
ревизију ове странице.
Ако је снимите, све промене учињене од ове ревизије биће изгубљене.</strong>",
"yourdiff"  => "Разлике",
"copyrightwarning" => "Молимо вас да обратите пажњу да се за сваки допринос Википедији
сматра да је објављен под ГНУ лиценцом за слободну документацију
(погледајте $1 за детаље).
Ако не желите да се ваше писање мења и редистрибуира
без ограничења, онда га немојте слати овде.<br />
Такође нам обећавате да сте га сами написали, или ископирали из
извора који је у јавном власништву или сличног слободног извора.
<strong>НЕ ШАЉИТЕ РАД ЗАШТИЋЕН АУТОРСКИМ ПРАВИМА БЕЗ ДОЗВОЛЕ!</strong>",
"longpagewarning" => "<strong>ПАЖЊА: Ова страница има $1 килобајта; неки
бровсери могу имати проблема са мењањем страница дугачких скоро 32кб или више.
Молимо вас да размотрите разбијање странице на мање делове.</strong>",
"readonlywarning" => "<strong>ПАЖЊА: База је ушраво закључана због одржавања,
тако да нећете моћи да снимите своје измене управо сада. Можда желите да ископирате и налепите
текст у текст едитор и снимите га за касније.</strong>",
"protectedpagewarning" => "<strong>ПАЖЊА:  Ова страница је закључана тако да само
корисници са сисопским привилегијама могу да је мењају. Уверите се да пратите
[[Project:Смернице_о_заштићеним_страницама|смернице о заштићеним страницама]].</strong>",

# History pages
#
"revhistory" => "Историја измена",
"nohistory"  => "Не постоји историја измена за ову страницу.",
"revnotfound" => "Ревизија није пронађена",
"revnotfoundtext" => "Старија ревизија ове странице коју сте затражили није нађена.
Молимо вас да проверите УРЛ који сте употребили да бисте приступили овој страници.\n",
"loadhist"  => "Учитавам историју странице",
"currentrev" => "Тренутна ревизија",
"revisionasof" => "Ревизија од $1",
"cur"   => "трен",
"next"   => "след",
"last"   => "посл",
"orig"   => "ориг",
"histlegend" => "Објашњење: (трен) = разлика са тренутном верзијом,
(посл) = разлика са претходном верзијом, М = мала измена",

# Diffs
#
"difference" => "(Разлика између ревизија)",
"loadingrev" => "учитавам ревизију за разлику",
"lineno"  => "Линија $1:",
"editcurrent" => "Измени тренутну верзију ове странице",

# Search results
#
"searchresults" => "Резултати претраге",
"searchresulttext" => "За више информација о претраживању Википедије, погледајте [[{{ns:4}}:Тражење|Претраживање Википедије]].",
"searchquery" => "За упит \"$1\"",
"badquery"  => "Лоше обликован упит за претрагу",
"badquerytext" => "Нисмо могли да обрадимо ваш упит.
Ово је вероватно због тога што сте покушалида тражите
реч краћу од три слова, што тренутно није подржано.
Такође је могуће да сте погрешно укуцали израз, на
пример \"риба ии крљушти\".
Молимо вас покушајте неким  другим упитом.",
"matchtotals" => "Упит \"$1\" је нађен у $2 наслова чланака
и текст $3 чланака.",
"nogomatch" => "Ниједна страница са оваквим насловом не постоји, покушавам претрагу свог текста.",
"titlematches" => "Наслов чланка одговара",
"notitlematches" => "Ниједан наслов чланка не одговара",
"textmatches" => "Текст чланка одговара",
"notextmatches" => "НИједан текст чланка не одговара",
"prevn"   => "претходних $1",
"nextn"   => "следећих $1",
"viewprevnext" => "Погледај ($1) ($2) ($3).",
"showingresults" => "Приказујем <b>$1</b> резултата почев од <b>$2</b>.",
"showingresultsnum" => "Приказујем <b>$3</b> резултате почев од <b>$2</b>.",
"nonefound"  => "<strong>Пажња</strong>: неуспешне претраге су
често изазване тражењем честих речи као \"је\" или \"од\",
које нису индексиране, или навођењем више од једног израза за тражење (само странице
које садрже све изразе који се траже ће се појавити у резултату).",
"powersearch" => "Тражи",
"powersearchtext" => "
Претрага и уменским просторима:<br />
$1<br />
$2 Излистај преусмерења &nbsp; Тражи $3 $9",
"searchdisabled" => "<p>Жалимо! Пуна претрага текста је привремено онемогућена, због бржег рада Википедије. Умеђувремену, можете користити Гугле претрагу испод, која може бити застарела.</p>

",
"blanknamespace" => "(Главно)",

# Preferences page
#
"preferences" => "Подешавања",
"prefsnologin" => "Нисте пријављени",
"prefsnologintext" => "Морате бити [[Special:Userlogin|пријављени]]
да бисте подешавали корисничка подешавања.",
"prefslogintext" => "Пријављени сте као \"$1\".
Ваш интерни ИД број је $2.

Погледајте [[{{ns:4}}:Помоћ око корисничких подешавања]] за помоћ око дешифровања могућности.",
"prefsreset" => "Враћена су ускладиштена подешавања.",
"qbsettings" => "Подешавања брзе палете",
"changepassword" => "Промени шифру",
"skin"   => "Кожа",
"math"   => "Приказивање математике",
"dateformat" => "Формат датума",
"math_failure"  => "Неуспех при парсирању",
"math_unknown_error" => "непозната грешка",
"math_unknown_function" => "непозната функција ",
"math_lexing_error" => "речничка грешка",
"math_syntax_error" => "синтаксна грешка",
"saveprefs"  => "Сними подешавања",
"resetprefs" => "Врати подешавања",
"oldpassword" => "Стара шифра",
"newpassword" => "Нова шифра",
"retypenew"  => "Поново откуцајте нову шифру",
"textboxsize" => "Величине текстуалног поља",
"rows"   => "Редова",
"columns"  => "Колона",
"searchresultshead" => "Подешавања резултата претраге",
"resultsperpage" => "Погодака по страници",
"contextlines" => "Линија по поготку",
"contextchars" => "Карактера контекста по линији",
"stubthreshold" => "Граница за приказивање окрњака",
"recentchangescount" => "Број наслова у скорашњим проенама",
"savedprefs" => "Ваша подешавања су снимљена.",
"timezonetext" => "Унесите број сати за који се ваше локално време
разликује од серверског времена (UTC).",
"localtime" => "Приказ локалног времена",
"timezoneoffset" => "Одступање",
"servertime" => "Време на серверу је сада",
"guesstimezone" => "Попуни из бровсера",
"emailflag"  => "Онемогући примање е-поште од осталих корисника",
"defaultns"  => "Уобичајено тражи у овим именским просторима:",
/*
</pre>
==Део 3==
<pre>
*/
# Recent changes
#
"changes" => "измене",
"recentchanges" => "Скорашње измене",
"recentchangestext" =>
"Пратите најскорије измене на Википедији овде.
[[Wikipedia:Добродошли|Добродошли]]!
Погледајте такође и: [[{{ns:4}}:FAQ|{{SITENAME}} FAQ]],
[[{{ns:4}}:Смернице|Википедијине смернице]]
(посебно [[{{ns:4}}:Правила именовања|правила именовања]],
[[{{ns:4}}:Неутрална тачка гледишта|неутрална тачка гледишта]]),
и [[{{ns:4}}:Најчешће грешке на Википедији|најчешће грешке на Википедији]].

Ако желите да {{SITENAME}} успе, веома је важно да не додајете
материјал ограничен туђим [[{{ns:4}}:Ауторска права|ауторским правима]].
Правна одговорност би могла да повреди пројекат, па вас молимо да то не радите.
Погледајте такође [http://meta.wikipedia.org/wiki/Special:Recentchanges скорашњу мета дискусију].",
"rcloaderr"  => "Учитавам скорашње измене",
"rcnote"  => "Испод је последњих <strong>$1</strong> промена у последњих <strong>$2</strong> дана.",
"rcnotefrom" => "Испод су промене од <b>$2</b> (до <b>$1</b> приказано).",
"rclistfrom" => "Покажи нове промене почев од $1",
# "rclinks"  => "Show last $1 changes in last $2 hours / last $3 days",
# "rclinks"  => "Show last $1 changes in last $2 days.",
"rclinks"  => "Покажи последљих $1 промена у последњих $2 дана; $3 мале измене",
"rchide"  => "у $4 облику; $1 мале измене; $2 секундарни именски простори; $3 вишеструке измене.",
"rcliu"   => "; $1 измена од пријављених корисника",
"diff"   => "разл",
"hist"   => "ист",
"hide"   => "скриј",
"show"   => "покажи",
"tableform"  => "табела",
"listform"  => "списак",
"nchanges"  => "$1 промена",
"minoreditletter" => "М",
"newpageletter" => "Н",

# Upload
#
"upload"  => "Пошаљи фајл",
"uploadbtn"  => "Пошаљи фајл",
"uploadlink" => "Пошаљи слике",
"reupload"  => "Поново пошаљи",
"reuploaddesc" => "Врати се на упитник за слање.",
"uploadnologin" => "Нисте пријављени",
"uploadnologintext" => "Морате бити [[Special:Userlogin|пријављени]]
да бисте слали фајлове.",
"uploaderror" => "Грешка при слању",
"uploadtext" => "'''СТОП!''' Пре него што шаљете овде,
обавезно прочитајте и пратите Википедијина
[[Project:Image_use_policy|правила коришћења слика]].

Да бисте прегледали или претраживали раније послате слике,
идите на [[Special:Imagelist|списак послатих слика]].
Слања и брисања су логована на
[[Project:Upload_log|логу слања]].

Употребите доњи упитник да бисте послали нове слике за
илустровање својих чланака.
На већини бровсера, видећете \"Browse...\" дугме, које ће вам
отворити стандардни прозор вашег оперативног система за бирање фајла.
Избор фајла ће убацити његово име у текст
поље поред дугмета.
Такође морате обележити кућицу чиме потврђујете да не
повређујете никаква ауторска права слањем фајла.
Притисните дугме \"Пошаљи\" да бисте завршили слање.
Оно може потрајати ако имате спору Интернет везу.

Пожељни формати су JPEG за фотографије, PNG
за цртеже и остале једноставне слике, и OGG за звуке.
Молимо вас да имена ваших фајлова имају неко значење да бисте избегли забуну.
Да бисте укључили слику у текст, употребите везу у облику
'''<nowiki>[[image:file.jpg]]</nowiki>''' или '''<nowiki>[[image:file.png|алтернативни текст]]</nowiki>'''
or '''<nowiki>[[media:file.ogg]]</nowiki>''' за звукове.

Обратите пажњу да, као и код Википедијиних страница, други могу мењати или
избрисати ваша слања ако мисле да то користи енциклопедији, а
може вам се и забранити да шаљете ако злоупотребите систем.",
"uploadlog"  => "лог слања",
"uploadlogpage" => "Лог_слања",
"uploadlogpagetext" => "Испод је списак најскоријих слања.
Сва времена су серверска времена (UTC).
<ul>
</ul>
",
"filename"  => "Име фајла",
"filedesc"  => "Опис",
"filestatus" => "Статус ауторских права",
"filesource" => "Извор",
"copyrightpage" => "{{ns:4}}:Ауторска_права",
"copyrightpagename" => "{{SITENAME}} ауторска права",
"uploadedfiles" => "Послати фајлови",
"ignorewarning" => "Игнориши упозорење и свеједно сними фајл.",
"minlength"  => "Имена слика морају имате бар три слова.",
"badfilename" => "Име слике је промељено у \"$1\".",
"badfiletype" => "\".$1\" није препоручени формат слике.",
"largefile"  => "Препоручује се да слике не пређу величину од 100К.",
"successfulupload" => "Успешно слање",
"fileuploaded" => "Фајл \"$1\" је успешно послат.
Молим пратите ову везу: ($2) до странице за описивање и унесите
информације о фајлу, као одакле је, када и
ко га је направио, ибило шта друго што знате о њему.",
"uploadwarning" => "Упозорење при слању",
"savefile"  => "Сними фајл",
"uploadedimage" => "послато \"[[$1]]\"",

# Image list
#
"imagelist"  => "Листа слика",
"imagelisttext" => "Испод је списак $1 слика поређаних $2.",
"getimagelist" => "прибављам списак слика",
"ilsubmit"  => "Тражи",
"showlast"  => "Прикажи последњих $1 слика поређаних по $2.",
"byname"  => "по имену",
"bydate"  => "по датуму",
"bysize"  => "по величини",
"imgdelete"  => "обр",
"imgdesc"  => "опис",
"imglegend"  => "Објашњење: (опис) = прикажи/измени опис слике.",
"imghistory" => "Историја слике",
"revertimg"  => "врт",
"deleteimg"  => "обр",
"deleteimgcompletely"  => "обр",
"imghistlegend" => "Објашњење: (трен) = ово је тренутна слика, (обр) = обриши
ову стару верзију, (врт) = врати на ову стару верзију.
<br /><i>Кликните на датум давидите слику послату тог датума</i>.",
"imagelinks" => "Употреба слике",
"linkstoimage" => "Следеће странице користе на ову слику:",
"nolinkstoimage" => "Нема страница које користе ову слику.",

# Statistics
#
"statistics" => "Статистике",
"sitestats"  => "Статистике сајта",
"userstats"  => "Статистике корисника",
"sitestatstext" => "Постоји укупно <b>$1</b> страница у бази.
Ово укључује \"разговор\" странице, странице о Википедији, минималне \"окрњке\",
преусмерења, и остале које се вероватно не могу сматрати чланцима.
Не рачунајући њих постоји <b>$2</b> страница које су вероватно легитимни
чланци.<p>
Странице су погледане <b>$3</b> пута, и мењане <b>$4</b> пута
откада је софтвер побољшан (20. јул 2002).
То значи да је у просеку било <b>$5</b> измена по страници, и <b>$6</b> прегледа по измени.",
"userstatstext" => "Постоји <b>$1</b> пријављених корисника.
<b>$2</b> њих су администратори (погледајте $3).",

# Maintenance Page
#
"maintenance"  => "Страница за одржавање",
"maintnancepagetext" => "Ова страница садржи неколико згодних алатки за свакодневно одржавање. Неке од њих могу заморити базу, па вас молимо да не учитавате поново после сваке ставке коју сте средили ;-)",
"maintenancebacklink" => "Назад на страницу за одржавање",
"disambiguations" => "Странице за обездвосмишљење",
"disambiguationspage" => "{{ns:4}}:Линкови_на_странице_за_обезвосмишљење",
"disambiguationstext" => "Следећи чланци се повезују са <i>страницом за обездвосмишљење</i>. Уместо тога, они би требали да се повезују са одговарајућом темом.<br />Страница се третира као обездвосмишљенска ако је повезана са $1.<br />Линкови из осталих именских простора <i>нису</i> наведени овде.",
"doubleredirects" => "Двострука преусмерења",
"doubleredirectstext" => "<b>Пажња:</b> Овај списак може да садржи лажне резултате. То обично значи да постоји додатни текст са везама испод првог #REDIRECT.<br />\nСваки ред садржи везе на прво и друго преусмерење, као и на прву линију текста другог преусмерења, што обично даје \"прави\" циљни чланак, на који би прво преусмерење и требало да показује.",
"brokenredirects" => "Покварена преусмерења",
"brokenredirectstext" => "Следећа преусмерења су повезана на непостојећи чланак.",
"selflinks"  => "Странице са самовезама",
"selflinkstext"  => "Следеће странице садрже везе на саме себе, што не би требало.",
"mispeelings"           => "Странице са грешкама у куцању",
"mispeelingstext"               => "Следеће странице садрже честе грешке у куцању, које су наведене на $1. Исправне речи могу бити дате (овако).",
"mispeelingspage"       => "Листа честих грешака у куцању",
"missinglanguagelinks"  => "Недостајући језичке везе",
"missinglanguagelinksbutton"    => "Нађи недостајуће језичке везе за",
"missinglanguagelinkstext"      => "Ови чланци <i>нису</i> повезани са њима одговарајућим у $1. Преусмерења и подстранице <i>нису</i> приказани.",


# Miscellaneous special pages
#
"orphans"  => "Сирочићи",
"lonelypages" => "Сирочићи",
"unusedimages" => "Неупотребљене слике",
"popularpages" => "Популарне странице",
"nviews"  => "$1 пута погледано",
"wantedpages" => "Тражене страице",
"nlinks"  => "$1 веза",
"allpages"  => "Све странице",
"randompage" => "Случајна страница",
"shortpages" => "Кратке странице",
"longpages"  => "Дугачке странице",
"listusers"  => "Листа корисника",
"specialpages" => "Посебне странице",
"spheading"  => "Посебне странице за све кориснике",
"protectpage" => "Заштити страницу",
"recentchangeslinked" => "Сродне промене",
"rclsub"  => "(на странице повезане од \"$1\")",
"debug"   => "Исправи грешке",
"newpages"  => "Нове странице",
"ancientpages"  => "Најстарији чланци",
"intl"  => "Међујезичке везе",
"movethispage" => "премести ову страницу",
"unusedimagestext" => "<p>Обратите пажњу да се други веб сајтови
као што су међународне Википедије могу повезивати на слику
директним УРЛ-ом, и тако могујош увек бити приказани овде упркос
активној употреби.",
"booksources" => "Штампани извори",
"booksourcetext" => "Испод је списак веза на друге сајтове који
продају нове и коришћене књиге, и такође могу имати даљње информације
о књигама које тражите.
{{SITENAME}} не сарађује ни се једним од ових предузећа, и
овај списак не треба да се схвати као потврда њиховог квалитета.",
"alphaindexline" => "$1 у $2",

# Email this user
#
"mailnologin" => "Нема адресе за слање",
"mailnologintext" => "Морате бити [[Special:Userlogin|пријављени]]
и имати исправну е-адресу in your [[Special:Preferences|подешавањима]]
да бисте слали електронску пошту другим корисницима.",
"emailuser"  => "Пошаљи е-писмо овом кориснику",
"emailpage"  => "Пошаљи е-писмо кориснику",
"emailpagetext" => "Ако је овај корисник унео исправну е-адресу у
своја корисничка подешавања, упитник испод ће послати једну поруку.
Е-адреса коју сте ви унели у своја корисничка подешавања ће се појавити
као \"From\" адреса поруке, тако да ће прималац моћи
да одговори.",
"noemailtitle" => "Нема е-адресе",
"noemailtext" => "Овај корисник није навео исправну е-адресу,
или је изабрао да не прима е-пошту од других корисника.",
"emailfrom"  => "Од",
"emailto"  => "За",
"emailsubject" => "Тема",
"emailmessage" => "Порука",
"emailsend"  => "Пошаљи",
"emailsent"  => "Порука послата",
"emailsenttext" => "Ваша порука је послата електронском поштом.",

# Watchlist
#
"watchlist"  => "Мој списак надгледања",
"watchlistsub" => "(за корисника \"$1\")",
"nowatchlist" => "Немате ништа на свом списку надгледања.",
"watchnologin" => "Нисте пријављени",
"watchnologintext" => "Морате бити [[Special:Userlogin|пријављени]]
да бисте мењали списак надгледања.",
"addedwatch" => "Додати списку надгледања",
"addedwatchtext" => "Страница \"$1\" је додата вашој <a href=\"" .
  "{{localurle:Special:Watchlist}}\">списку надгледања</a>.
Будуће промене ове странице и њој придружене странице за разговор ће бити наведене овде,
и страница ће бити <b>подебљана</b> у <a href=\"" .
  "{{localurle:Special:Recentchanges}}\">списку скорашњих измена</a> да
би се лакше уочила.</p>

<p>Ако касније желите да уклоните страницу са вашег списка надгледања, кликните на \"Прекини надгледање\" на бочној палети.",
"removedwatch" => "Уклоњено из списка надгледања",
"removedwatchtext" => "Страница \"$1\" је уклоњена из вашег списка надгледања.",
"watchthispage" => "Надгледај ову страницу",
"unwatchthispage" => "Прекини надгледање",
"notanarticle" => "Није чланак",
"watchnochange" => "Ништа што надгледате није промењено у приказаном времену.",
"watchdetails" => "($1 страница надгледано не рачунајући странице за разговор;
$2 укупно страница измењено од одсецања;
$3...
[$4 прикажи и мењај потпуни списак].)",
"watchmethod-recent" => "проверавам има ли надгледаних страница у скорашњим изменама",
"watchmethod-list" => "проверавам има ли скорашњих измена у надгледаним страницама",
"removechecked" => "Уклони обележене уносе из списка надгледања",
"watchlistcontains" => "Ваш списак надгледања садржи $1 страница.",
"watcheditlist" => "Овде је азбучни списак страница
које надгледате. Обележите кућице страница које желите да уклоните
са свог списка надгледања и кликните на дугме 'уклони изабране'
на дну екрана.",
"removingchecked" => "Уклањам обележене ствари са списка надгледања...",
"couldntremove" => "Не могу да уклоним '$1'...",
"iteminvalidname" => "Проблем са '$1', неисправно име...",
"wlnote" => "Испод је последњих $1 измена у последњих <b>$2</b> сати.",
"wlshowlast" => "Прикажи последњих $1 сати $2 дана $3",


# Delete/protect/revert
#
"deletepage" => "Обриши страницу",
"confirm"  => "Потврди",
"excontent" => "садржај је био: '$1'",
"exbeforeblank" => "садржај пре брисања је био: '$1'",
"exblank" => "страница је била празна",
"confirmdelete" => "Потврди брисање",
"deletesub"  => "(Бришем \"$1\")",
"historywarning" => "Пажња: страница коју желите да обришете има историју: ",
"confirmdeletetext" => "На путу сте да трајно обришете страницу
или слику заједно са свом њеномисторијом из базе.
Молим вас потврдите да намеравате да урадите ово, да разумете
последице, и да ово радите у складу са
[[{{ns:4}}:Правила]].",
"actioncomplete" => "Акција завршена",
"deletedtext" => "\"$1\" је обрисана.
Погледајте $2 за запис о скорашњим брисањима.",
"deletedarticle" => "обрисан \"$1\"",
"dellogpage" => "Лог_брисања",
"dellogpagetext" => "Испод је списак најскоријих брисања.
Сва приказана времене су серверска (UTC).
<ul>
</ul>
",
"deletionlog" => "Лог брисања",
"reverted"  => "Враћено на ранију ревизију",
"deletecomment" => "Разлог за брисање",
"imagereverted" => "Враћање на ранију верзију је успешно.",
"rollback"  => "Врати измене",
"rollbacklink" => "врати",
"rollbackfailed" => "Враћање није успело",
"cantrollback" => "Не могу да вратим измену; последњи аутор је уједно и једини.",
"alreadyrolled" => "Не могу да вратим последњу измену [[$1]]
од корисника [[Корисник:$2|$2]] ([[Разговор са корисником:$2|Разговор]]); неко други је већ изменио или врати чланак.

Последња измена од корисника [[Корисник:$3|$3]] ([[Разговор са корисником:$3|Разговор]]). ",
#   only shown if there is an edit comment
"editcomment" => "Коментар измене је: \"<i>$1</i>\".",
"revertpage" => "Враћено на последњу измену од корисника $1",

# Undelete
"undelete" => "Врати обрисану страницу",
"undeletepage" => "Погледај и врати обрисане странице",
"undeletepagetext" => "Следеће странице су обрисане али су још увек у архиви и
могу бити враћене. Архива може бити периодично чишћена.",
"undeletearticle" => "Врати обрисани чланак",
"undeleterevisions" => "$1 ревизија архивирано",
"undeletehistory" => "Ако вратите страницу, све ревизије ће бити враћене њеној историји.
Ако јенова страница истог имена направљена од брисања, враћене
ревизије ће се појавити у ранијој историји, а тренутна ревизија садашње странице
неће бити аутоматски замењена.",
"undeleterevision" => "Обрисана ревизија од $1",
"undeletebtn" => "Врати!",
"undeletedarticle" => "враћено \"$1\"",
"undeletedtext"   => "Чланак [[$1]] је успешно враћен.
Погледајте [[{{ns:4}}:Лог_брисања]] за запис о скорашњим брисањима и враћањима.",

# Contributions
#
"contributions" => "Прилози корисника",
"mycontris" => "Моји прилози",
"contribsub" => "За $1",
"nocontribs" => "Нису нађене промене које задовољавају ове услове.",
"ucnote"  => "Испод је последњих <b>$1</b> промена у последњих <b>$2</b> дана.",
"uclinks"  => "Гледај последњих $1 промена; гледај последњих $2 дана.",
"uctop"  => " (врх)" ,

# What links here
#
"whatlinkshere" => "Шта је повезано овде",
"notargettitle" => "Нема циља",
"notargettext" => "Нисте навели циљну страницу или корисника
на коме би се извела ова функција.",
"linklistsub" => "(Листа веза)",
"linkshere"  => "Следеће странице су повезане овде:",
"nolinkshere" => "Ни једна страница није повезана овде.",
"isredirect" => "Преусмеривач",

# Block/unblock IP
#
"blockip"  => "Обуздај корисника",
"blockiptext" => "Употребите доњи упитник да бисте уклонили право писања
са одређене ИП адресе или корисничког имена.
Ово би требало да буде урађено само да би се спречио вандализам, и у складу
са [[{{ns:4}}:Смернице|Википедијиним смерницама]].
Унесите конкретан разлог испод (на пример, наводећи које
странице су вандализоване).",
"ipaddress"  => "ИП адреса/корисничко име",
"ipbreason"  => "Разлог",
"ipbsubmit"  => "Обуздај овог корисника",
"badipaddress" => "Не постоји ниједан корисник који се тако зове",
"blockipsuccesssub" => "Обуздавање је успело",
"blockipsuccesstext" => "\"$1\" је обуздан.
<br />Погледајте [[Посебно:ИПсписакаобузданих|ИП списак обузданих]] за преглед обуздавања.",
"unblockip"  => "Отпусти корисника",
"unblockiptext" => "Употребите доњи упитник да бист вратили право писања
раније обузданој ИП адреси или корисничком имену.",
"ipusubmit"  => "Отпусти ову адресу",
"ipusuccess" => "\"$1\" отпуштен",
"ipblocklist" => "Списак обузданих ИП адреса и корисника",
"blocklistline" => "$1, $2 је обуздао $3 ($4)",
"blocklink"  => "блокирај",
"unblocklink" => "деблокирај",
"contribslink" => "прилози",
"autoblocker" => "Аутоматски сте обуздани јер делите ИП адресу са \"$1\". Разлог \"$2\".",
# Developer tools
#
"lockdb"  => "Закључај базу",
"unlockdb"  => "Откључај базу",
"lockdbtext" => "Закључавање базе ће свим корисницима укинути могућност измене страница,
промене корисничких подешавања, измене списка надгледања, и свега осталог
што захтева промене у бази.
Молим потврдите да је ово заиста оно што намеравате да урадите, и да ћете
откључати базу када завршите посао око њеног одржавања.",
"unlockdbtext" => "Откључавање базе ће свим корисницима вратити могућност измене страница,
промене корисничких подешавања, измене списка надгледања, и свега осталог
што захтева промене у бази.
Молим потврдите да је ово заиста оно што намеравате да урадите.",
"lockconfirm" => "Да, заиста желим да закључам базу.",
"unlockconfirm" => "Да, заиста желим да откључам базу.",
"lockbtn"  => "Закључај базу",
"unlockbtn"  => "Откључај базу",
"locknoconfirm" => "Нисте потврдили своју намеру.",
"lockdbsuccesssub" => "База је закључана",
"unlockdbsuccesssub" => "База је откључана",
"lockdbsuccesstext" => "Википедијина база података је закључана.
<br />Сетите се да је откључате када завршите са одржавањем.",
"unlockdbsuccesstext" => "Википедијина база података је откључана.",

# Move page
#
"movepage"  => "Премештање странице",
"movepagetext" => "Доњи упитник ће преименовати страницу, премештајући сву
њену историју на ново име.
Стари наслов ће постати преусмерење на нови наслов.
Линкови према старом наслову неће бити промењени; обавезно
[[Посебно:Одржавање|потражите]] двострука или покварена преусмерења.
На вама је одговорност да везе и даље иду
тамо где би и требало да иду.

Обратите пажњу да страница '''неће''' бити померена ако већ постоји
страница са новим насловом, осим ако је она празна или преусмерење и нема
историју промена. Ово значи да не можете преименовати страницу на оно име
са кога сте је преименовали ако погрешите, и не можете преписати
постојећу страницу.

<b>ПАЖЊА!</b>
Ово може бити драстична и неочекивана промена за популарну страницу;
молимо да будете сигурни да разумете последице овога пре него што
наставите.",
"movepagetalktext" => "Одговарајућа страница за разговор, ако постоји, ће бити аутоматски премештена истовремено '''осим:'''
*Ако премештате страницу preko именских простора,
*Непразна страница за разговор већ постоји под новим именом, или
*Одбележите доњу кућицу.

У тим случајевима, мораћете ручно да преместите страницу уколико то желите.",
"movearticle" => "Премести страницу",
"movenologin" => "Нисте улоговани",
"movenologintext" => "Морате бити регистровани корисник и [[Special:Userlogin||пријављени]]
да бисте преместили страницу.",
"newtitle"  => "Нови наслов",
"movepagebtn" => "премести страницу",
"pagemovedsub" => "Премештање успело",
"pagemovedtext" => "Страница \"[[$1]]\" премештена је на \"[[$2]]\".",
"articleexists" => "Страница под тим именом већ постоји, или
име које сте изабрали није исправно.
Молим изаберите друго име.",
"talkexists" => "Сама страница је успешно премештена, али
страница за разговор није могла бити премештена јер таква већ постоји на новом наслову. Молим да их спојите ручно.",
"movedto"  => "премештена на",
"movetalk"  => "Премести \"страницу за разговор\" такође, ако је могуће.",
"talkpagemoved" => "Одговарајућа страницаза разговор је такође премештена.",
"talkpagenotmoved" => "Одговарајућа страница за разговор <strong>није</strong> премештена.",

"export"  => "Извези странице",
"exporttext" => "Можете извести текст и историју промена одређене
странице или групе страница умотану у неки XML; ово онда може бити увезено у други
вики који користи МедијаВики софтвер, трансформисано, или коришћено за ваше личне
потребе.",
"exportcuronly" => "Укључи само тренутну ревизију, не целу историју",

# Namespace 8 related

"allmessages" => "Све_поруке",
"allmessagestext" => "Ово је списак свих порука које су у МедијаВики: именском простору",

# Math

'mw_math_png' => "Увек прикажи PNG",
'mw_math_simple' => "HTML ако је врло једноставно, иначе PNG",
'mw_math_html' => "HTML ако је могуће, иначе PNG",
'mw_math_source' => "Остави као ТеХ (за текстуалне бровсере)",
'mw_math_modern' => "Препоручено за савремене бровсере",

);

#--------------------------------------------------------------------------
# Internationalisation code
#--------------------------------------------------------------------------

class LanguageSr extends LanguageUtf8 {

	function getNamespaces() {
	global $wgNamespaceNamesSr;
	return $wgNamespaceNamesSr;
	}

	function getNsIndex( $text ) {
	global $wgNamespaceNamesSr;

	foreach ( $wgNamespaceNamesSr as $i => $n ) {
		if ( 0 == strcasecmp( $n, $text ) ) { return $i; }
	}
	if( 0 == strcasecmp( "Special", $text ) ) { return -1; }
	if( 0 == strcasecmp( "User", $text ) ) { return 2; }
	if( 0 == strcasecmp( "Wikipedia", $text ) ) { return 4; }
	return false;
	}

	function getQuickbarSettings() {
	global $wgQuickbarSettingsSr;
	return $wgQuickbarSettingsSr;
	}

	function getSkinNames() {
	global $wgSkinNamesSr;
	return $wgSkinNamesSr;
	}

	function getDateFormats() {
	global $wgDateFormatsSr;
	return $wgDateFormatsSr;
	}

	function getMessage( $key ) {
		global $wgAllMessagesSr;
		if(array_key_exists($key, $wgAllMessagesSr))
			return $wgAllMessagesSr[$key];
		else
			return parent::getMessage($key);
	}

	function formatNum( $number, $year = false ) {
		return $year ? $number : strtr($this->commafy($number), '.,', ',.' );
	}

	/**
	 * @access public
	 * @param mixed  $ts the time format which needs to be turned into a
	 *               date('YmdHis') format with wfTimestamp(TS_MW,$ts)
	 * @param bool   $adj whether to adjust the time output according to the
	 *               user configured offset ($timecorrection)
	 * @param mixed  $format what format to return, if it's false output the
	 *               default one.
	 * @param string $timecorrection the time offset as returned by
	 *               validateTimeZone() in Special:Preferences
	 * @return string
	 */
	function date( $ts, $adj = false, $format = true, $timecorrection = false ) {

		if ( $adj ) { $ts = $this->userAdjust( $ts, $timecorrection ); }

		$mm = substr( $ts, 4, 2 );
		$m = 0 + $mm;
		$mmmm = $this->getMonthName( $mm );
		$mmm = $this->getMonthAbbreviation( $mm );
		$dd = substr( $ts, 6, 2 );
		$d = 0 + $dd;
		$yyyy =  substr( $ts, 0, 4 );
		$yy =  substr( $ts, 2, 2 );

		switch( $format ) {
			case '2':
			case '8':
				return "$d $mmmm $yyyy";
			case '3':
			case '9':
				return "$dd.$mm.$yyyy.";
			case '4':
			case '10':
				return "$d.$m.$yyyy.";
			case '5':
			case '11':
				return "$d. $mmm $yyyy.";
			case '6':
			case '12':
				return "$d $mmm $yyyy";
			default:
				return "$d. $mmmm $yyyy.";
		}

	}

	/**
	* @access public
	* @param mixed  $ts the time format which needs to be turned into a
	*               date('YmdHis') format with wfTimestamp(TS_MW,$ts)
	* @param bool   $adj whether to adjust the time output according to the
	*               user configured offset ($timecorrection)
	* @param mixed  $format what format to return, if it's false output the
	*               default one (default true)
	* @param string $timecorrection the time offset as returned by
	*               validateTimeZone() in Special:Preferences
	* @return string
	*/
	function time( $ts, $adj = false, $format = true, $timecorrection = false ) {

		if ( $adj ) { $ts = $this->userAdjust( $ts, $timecorrection ); }
		$hh = substr( $ts, 8, 2 );
		$h = 0 + $hh;
		$mm = substr( $ts, 10, 2 );
		switch( $format ) {
			case '7':
			case '8':
			case '9':
			case '10':
			case '11':
			case '12':
				return "$h:$mm";
			default:
				return "$hh:$mm";
		}
	}

	/**
	* @access public
	* @param mixed  $ts the time format which needs to be turned into a
	*               date('YmdHis') format with wfTimestamp(TS_MW,$ts)
	* @param bool   $adj whether to adjust the time output according to the
	*               user configured offset ($timecorrection)
	* @param mixed  $format what format to return, if it's false output the
	*               default one (default true)
	* @param string $timecorrection the time offset as returned by
	*               validateTimeZone() in Special:Preferences
	* @return string
	*/
	function timeanddate( $ts, $adj = false, $format = true, $timecorrection = false) {
		$datePreference = $this->dateFormat($format);
		return $this->time( $ts, $adj, $datePreference, $timecorrection ) . ', ' . $this->date( $ts, $adj, $datePreference, $timecorrection );

	}


}

?>
